@@ -50,3 +50,25 @@ model_get_model_frame.survreg <- function(model) {
     }
   )
 }
+
+
+#' @export
+#' @rdname model_get_model_frame
+model_get_model_frame.biglm <- function(model) {
+  stats::model.frame(
+    stats::formula(model),
+    data = stats::model.frame.default(model)
+  )
+}
+
+#' @export
+#' @rdname model_get_model_frame
+model_get_model_frame.model_fit <- function(model) {
+  model_get_model_frame(model$fit)
+}
+
+#' @export
+#' @rdname model_get_model_frame
+model_get_model_frame.fixest <- function(model) {
+  stats::model.frame.default(model$fml, data = get(model$call$data, model$call_env))
+}
