@@ -85,3 +85,25 @@ model_get_model_matrix.glmmTMB <- function(model, ...) {
 model_get_model_matrix.plm <- function(model, ...) {
   stats::model.matrix(model, cstcovar.rm = "none", ...)
 }
+
+
+#' @export
+#' @rdname model_get_model_matrix
+model_get_model_matrix.biglm <- function(model, ...) {
+  stats::model.matrix(
+    model,
+    data = stats::model.frame.default(model)
+  )
+}
+
+#' @export
+#' @rdname model_get_model_matrix
+model_get_model_matrix.model_fit <- function(model, ...) {
+  model_get_model_matrix(model$fit, ...)
+}
+
+#' @export
+#' @rdname model_get_model_matrix
+model_get_model_matrix.fixest <- function(model, ...) {
+  stats::model.matrix.default(model$fml, data = get(model$call$data, model$call_env), ...)
+}
